<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Static Pages Plugin 1.2 for Geeklog - The Ultimate Weblog                 |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the Static     |
// | Pages' PHP files.                                                         |
// |                                                                           |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2000,2001 by the following authors:                         |
// |                                                                           |
// | Authors: Tony Bibbs       - tony@tonybibbs.com                            |
// |          Tom Willett      - tomw@pigstye.net                              |
//            Blaine Lang
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
// $Id: functions.inc,v 1.5 2002/04/23 04:22:02 mlimburg Exp $

$langfile = $_CONF['path'] . 'plugins/staticpages/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) {
    include ($langfile);
} else {
    include ($_CONF['path'] . 'plugins/staticpages/language/english.php');
}

include($_CONF['path'] . 'plugins/staticpages/config.php');

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementations                                        |
// +---------------------------------------------------------------------------+



/**
* Returns the items for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
*/
function plugin_getmenuitems_staticpages()
{
    global $_CONF, $_TABLES;

    $result = DB_query('SELECT sp_id, sp_label, sp_pos, group_id, owner_id, perm_owner, perm_group, perm_members, perm_anon FROM ' . $_TABLES['staticpage'] . ' WHERE sp_onmenu = 1 ORDER BY sp_pos');
    $nrows = DB_numRows($result);
    $menuitems = array();
    for ($i = 1; $i <= $nrows; $i++) {
        $A = DB_fetchArray($result);
        if(SEC_hasAccess($A[owner_id],$A[group_id],$A[perm_owner],$A[perm_group],$A[perm_members],$A[perm_anon])){
	        $menuitems[$A['sp_label']] = $_CONF['site_url'] . "/staticpages/index.php?page={$A['sp_id']}";
    	}
    }
    return $menuitems;
}

/**
* Geeklog is checking to see if this plugin supports comments, tell it yes!
* NOTE: to support comments you must used the same date/time based ID for your
* widget.  In otherwords, to make primary keys for your plugin you should call
* makesid().  Comments are keyed off of that...it is a limitation on how geeklog
* does comments.
*
*/
function plugin_commentsupport_staticpages() 
{
    // Static Pages will not use comments
    return false;
}

/**
* shows the statistics for the book review plugin on stats.php.  If $showsitestats
* is 1 then we are to only print the overall stats in the 'site statistics box'
* otherwise we show the detailed stats for the photo album
*
* @showsitestate        int         Flag to let us know which stats to get
*/
function plugin_showstats_staticpages($showsitestats) 
{
    global $LANG_STATIC, $_CONF, $_TABLES;

    $stat_templates = new Template($_CONF['path_layout'] . 'stats');
    $stat_templates->set_file(array('itemstats'=>'itemstatistics.thtml',
                            'statrow'=>'singlestat.thtml'));
    if ($showsitestats == 1) {
        $total_pages=DB_count('gl_staticpage');
        $retval = "<table border = '0' width='100%' cellspacing='0' cellpadding='0'>";
        $retval .= "<tr><td>" . $LANG_STATIC[staticpages] . "</td>";
        $retval .= "<td align='right'>" . $total_pages . "&nbsp;&nbsp </td></tr></table>";
    } else {
        $result = DB_query("SELECT sp_id, sp_title, sp_hits from {$_TABLES['staticpage']} WHERE sp_hits > 0 ORDER BY sp_hits desc LIMIT 10");
        $nrows  = DB_numRows($result);
        $retval .= COM_startBlock("Top Ten Static Pages");
        if ($nrows > 0) {
            $stat_templates->set_var('item_label',"Page Title");
            $stat_templates->set_var('stat_name',"Hits");
            for ($i = 0; $i < $nrows; $i++) {
                $A = DB_fetchArray($result);
                $stat_templates->set_var('item_url', $_CONF['site_url'] . '/staticpages/index.php?page=' . $A['sp_id']);
                $stat_templates->set_var('item_text', stripslashes($A['sp_title']));
                $stat_templates->set_var('item_stat', $A['sp_hits']);
                $stat_templates->parse('stat_row','statrow',true); 
            }
            $stat_templates->parse('output','itemstats');
            $retval .= $stat_templates->finish($stat_templates->get_var('output'));
        } else {
            $retval .= 'It appears that there are no stories on this site or no one has ever viewed them.';
        }	
        $retval .= COM_endBlock();
    }
    return $retval;
}

/**
* Geeklog is asking us to provide any new items that show up in the type drop-down
* on search.php.  Let's let users search static pages!
*
*/
function plugin_searchtypes_staticpages() 
{
    global $LANG_STATIC;

    $tmp['staticpages'] = $LANG_STATIC['staticpages'];
    return $tmp;
}


/**
* this searches for static pages matching the user query and returns an array of 
* for the header and table rows back to search.php where it will be formated and
* printed 
*
* @query            string          Keywords user is looking for
* @datestart        date/time       Start date to get results for
* @dateend          date/time       End date to get results for
* @topic            string          The topic they were searching in
* @type             string          Type of items they are searching
* @author           string          Get all results by this author
*
* Oct 05/2002: Blaine Lang, Corrected bug with SQL Search string. 
*/
function plugin_dopluginsearch_staticpages($query, $datestart, $dateend, $topic, $type, $author) 
{
	global $_TABLES, $_CONF;

    if (empty($type)) {
        $type = 'all';
    }
    
    // Bail if we aren't supppose to do our search
    if ($type <> 'all' AND $type <> 'staticpages') {
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = 'staticpages';
        $plugin_results->searchlabel = 'Static Pages Results';
        return $plugin_results;
    }

    // Build search SQL - Modified to exclude static PHP pages from search.
	$sql = "SELECT *,UNIX_TIMESTAMP(sp_date) as day FROM " . $_TABLES['staticpage'] . " WHERE (sp_php != '1' AND";
    $sql .= "((sp_content like '%$query%' OR sp_content like '$query%' OR sp_content like '%$query') ";
    $sql .= "OR (sp_title like '%$query%' OR sp_title like '$query%' OR sp_title like '%$query')";
    $sql .= "OR (sp_search_keywords like '%$query%' OR sp_search_keywords like '$query%' OR sp_search_keywords like '%$query'))";
		    
    if (!empty($datestart) && !empty($dateend)) {
        $delim = substr($datestart, 4, 1);
        $DS = explode($delim,$datestart);
        $DE = explode($delim,$dateend);
        $startdate = mktime(0,0,0,$DS[1],$DS[2],$DS[0]);
		$enddate = mktime(23,59,59,$DE[1],$DE[2],$DE[0]);
        $sql .= " AND (UNIX_TIMESTAMP(sp_date) BETWEEN '$startdate' AND '$enddate')";
    }

    if (!empty($author)) {
        $sql .= "AND (sp_uid = '$author') ";
    }
    $sql    .= ") ORDER BY sp_date desc";

    // Perform search
    $result = DB_query($sql);
    
    // OK, now return coma delmited string of table header labels
    require_once($_CONF['path_system'] . 'classes/plugin.class.php');
    $plugin_results = new Plugin();
    $plugin_results->plugin_name = 'staticpages';
    $plugin_results->searchlabel = 'Static Pages Results';
    $plugin_results->addSearchHeading('Title');
    $plugin_results->addSearchHeading('Last Updated');
    $plugin_results->addSearchHeading('Author');
    $plugin_results->addSearchHeading('Hits');
    $mycount = DB_numRows($result);

    // NOTE if any of your data items need to be links then add them here! 
    // make sure data elements are in an array and in the same order as your
    // headings above!
	for ($i = 1; $i <= $mycount; $i++) {
        $A = DB_fetchArray($result);

     if(SEC_hasAccess($A[owner_id],$A[group_id],$A[perm_owner],$A[perm_group],$A[perm_members],$A[perm_anon])){
       $rcnt++;
        $thetime = COM_getUserDateTimeFormat($A['day']);
        $A['sp_title'] = stripslashes($A['sp_title']);
        $row = array("<a href={$_CONF['site_url']}/staticpages/index.php?page={$A['sp_id']}>{$A['sp_title']}</a>",
                    $thetime[0],
                    "<a href={$_CONF['site_url']}/users.php?mode=profile&uid={$A['sp_uid']}>".DB_getItem($_TABLES['users'],'username',"uid = '{$A["sp_uid"]}'")."</a>",
                    $A['sp_hits']);
        $plugin_results->addSearchResult($row);
	 }
	
	}
    $plugin_results->num_searchresults = $rcnt;
    $plugin_results->num_itemssearched = DB_count($_TABLES['staticpage']);

    return $plugin_results;
}


/**
* This will put an option for static pages in the command and control block on
* moderation.php
*
*/
function plugin_cclabel_staticpages() 
{
    global $LANG_STATIC, $_CONF;

    // Need to change to not hardcode the language
    return array($LANG_STATIC['staticpages'],$_CONF['site_admin_url'] . '/plugins/staticpages/index.php',$_CONF['site_url'] . '/staticpages/images/staticpages.gif');
}

/**
* returns the administrative option for this plugin
*
*/


function plugin_getadminoption_staticpages() 
{
    global $_CONF, $LANG_STATIC, $_TABLES;

    if (SEC_hasRights('staticpages.edit,staticpages.delete','OR')) {
        return array($LANG_STATIC[staticpages], $_CONF['site_admin_url'] . '/plugins/staticpages/index.php', DB_count($_TABLES['staticpage']));
    }	
}

?>
